@@ -1,6 +1,7 @@
 import os
 import click
 import json
+import getpass
 from appdirs import user_config_dir
 
 from engine import __version__ as version
@@ -10,7 +11,7 @@ from engine.connections import Callisto
 from .project import project 
 from .experiment import experiment
 
-    
+
 @click.group()
 @click.version_option(version, message='%(version)s')
 def cli():
@@ -19,29 +20,26 @@ def cli():
         os.makedirs(config_dir)
     if not os.path.exists(os.path.join(config_dir, "config.json")):
         fout = open(os.path.join(config_dir, "config.json"), "w")
-        json.dump({"host": None,
+        json.dump({"host": 'https://api.granular.ai',
                     "org":  None, 
-                   "email": None,   
-                   "password": None, 
-                   "cookie": None}, fout)
+                   "email": None}, fout)
         fout.close()
 
 @click.command()
 @click.option('--host', required=False, type=str, 
                 default='https://api.granular.ai', 
                 help='Platform root address')
-@click.option('--email', required=True, type=str,
-                help='Email registered on GeoEngine')
-@click.option('--password', required=True, type=str,
-                help='Password registered in GeoEngine')
-def login(host, email, password):
+def login(host):
     """Login on GeoEngine platform
 
     Examples:
 
     \b
-    $ engine login --email=EMAIL --password=PASSWORD
+    $ engine login 
     """
+    email = input("Email: ")
+    password = getpass.getpass()
+
     callisto = Callisto(email=email, password=password, host=host)
 
 cli.add_command(login)
